# SELF HEALING AUTOMATION AGENT

Run this command from your root directory to start the automation agent `pytest -v -s src/automation/tests/test_case.py`

If everything is okay then no agentic work will happen.

In case any error happens then the agent will work and start to find the the cause of the error and try givin gsome suggestion.